# Hopfield-NLMIP

[![Build Status](https://travis-ci.org/mathildebadoual/hmip.svg?branch=master)](https://travis-ci.org/mathildebadoual/hmip) [![codecov](https://codecov.io/gh/mathildebadoual/hmip/branch/master/graph/badge.svg)](https://codecov.io/gh/mathildebadoual/hmip)
[![Pypi version](https://img.shields.io/pypi/v/hmip.svg)](https://pypi.python.org/pypi/hmip/)

Solver for large scale nonlinear mixed integer problems. Work published as "Dual Hopfield Methods for Large-Scale Mixed-Integer Programming", B. Travacca, S. J. Moura, 2018 IEEE Conference on Decision and Control (CDC) [[link]](https://ecal.berkeley.edu/pubs/CDC18_DualHopfield.pdf)

Developed at [eCAL](https://ecal.berkeley.edu/), UC Berkeley.

Work funded by [TOTAL](https://www.total.com/en).  


# Installation

```bash
pip install hmip
```

# Running

```python
import hmip
```

For examples of how to use the module, run the [jupyter notebook](https://github.com/mathildebadoual/hmip/blob/master/examples/hmip_2d_example.ipynb) and read the [Wiki](https://github.com/mathildebadoual/hmip/wiki).

# Contacts:

Mathilde Badoual: mathilde.badoual@berkeley.edu

Bertand Travacca: bertrand.travacca@berkeley.edu
